==> cookiecutter-pypackage-instance-0.1.0.tar.gz: cookiecutter-pypackage-instance-0.1.0/README.md <==
<h1 align="center">🐍 Cookiecutter Pypackage Instance</h1>

<p align="center">
  <a href="https://www.python.org/">
    <img
      src="https://img.shields.io/pypi/pyversions/cookiecutter-pypackage-instance"
      alt="PyPI - Python Version"
    />
  </a>
  <a href="https://pypi.org/project/cookiecutter-pypackage-instance/">
    <img
      src="https://img.shields.io/pypi/v/cookiecutter-pypackage-instance"
      alt="PyPI"
    />
  </a>
  <a href="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/ci.yml">
    <img
      src="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/ci.yml/badge.svg"
      alt="CI"
    />
  </a>
  <a href="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/cd.yml">
    <img
      src="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/cd.yml/badge.svg"
      alt="CD"
    />
  </a>
  <a href="https://results.pre-commit.ci/latest/github/billsioros/cookiecutter-pypackage-instance/master">
    <img
      src="https://results.pre-commit.ci/badge/github/billsioros/cookiecutter-pypackage-instance/master.svg"
      alt="pre-commit.ci status"
    />
  </a>
  <a href="https://codecov.io/gh/billsioros/cookiecutter-pypackage-instance">
    <img
      src="https://codecov.io/gh/billsioros/cookiecutter-pypackage-instance/branch/master/graph/badge.svg?token=coLOL0j6Ap"
      alt="Test Coverage"/>
  </a>
  <a href="https://opensource.org/licenses/MIT">
    <img
      src="https://img.shields.io/pypi/l/cookiecutter-pypackage-instance"
      alt="PyPI - License"
    />
  </a>
  <a href="https://gitpod.io/from-referrer/">
    <img
      src="https://img.shields.io/badge/Open%20on-Gitpod-blue?logo=gitpod&style=flat"
      alt="Open on Gitpod"
    />
  </a>
  <a href="https://github.com/billsioros/cookiecutter-pypackage">
    <img
      src="https://img.shields.io/badge/cookiecutter-template-D4AA00.svg?style=flat&logo=cookiecutter"
      alt="Cookiecutter Template">
  </a>

</p>

## Example Usage

```python
>>> from cookiecutter_pypackage_instance import cookiecutter_pypackage_instance
```

## Features

- TODO

## Documentation

The project's documentation can be found [here](https://billsioros.github.io/cookiecutter-pypackage-instance/).

## Installation

```bash
pip install cookiecutter-pypackage-instance
```

## Supporting the project

Feel free to [**Buy me a coffee! ☕**](https://www.buymeacoffee.com/billsioros).

## Contributing

If you would like to contribute to the project, please go through the [Contributing Guidelines](https://billsioros.github.io/cookiecutter-pypackage-instance/latest/CONTRIBUTING/) first.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [billsioros/cookiecutter-pypackage](https://github.com/billsioros/cookiecutter-pypackage) cookiecutter template.

==> cookiecutter-pypackage-instance-0.1.1.tar.gz: cookiecutter-pypackage-instance-0.1.1/README.md <==
<h1 align="center">🐍 Cookiecutter Pypackage Instance</h1>

<p align="center">
  <a href="https://www.python.org/">
    <img
      src="https://img.shields.io/pypi/pyversions/cookiecutter-pypackage-instance"
      alt="PyPI - Python Version"
    />
  </a>
  <a href="https://pypi.org/project/cookiecutter-pypackage-instance/">
    <img
      src="https://img.shields.io/pypi/v/cookiecutter-pypackage-instance"
      alt="PyPI"
    />
  </a>
  <a href="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/ci.yml">
    <img
      src="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/ci.yml/badge.svg"
      alt="CI"
    />
  </a>
  <a href="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/cd.yml">
    <img
      src="https://github.com/billsioros/cookiecutter-pypackage-instance/actions/workflows/cd.yml/badge.svg"
      alt="CD"
    />
  </a>
  <a href="https://results.pre-commit.ci/latest/github/billsioros/cookiecutter-pypackage-instance/master">
    <img
      src="https://results.pre-commit.ci/badge/github/billsioros/cookiecutter-pypackage-instance/master.svg"
      alt="pre-commit.ci status"
    />
  </a>
  <a href="https://codecov.io/gh/billsioros/cookiecutter-pypackage-instance">
    <img
      src="https://codecov.io/gh/billsioros/cookiecutter-pypackage-instance/branch/master/graph/badge.svg?token=coLOL0j6Ap"
      alt="Test Coverage"/>
  </a>
  <a href="https://opensource.org/licenses/MIT">
    <img
      src="https://img.shields.io/pypi/l/cookiecutter-pypackage-instance"
      alt="PyPI - License"
    />
  </a>
  <a href="https://gitpod.io/from-referrer/">
    <img
      src="https://img.shields.io/badge/Open%20on-Gitpod-blue?logo=gitpod&style=flat"
      alt="Open on Gitpod"
    />
  </a>
  <a href="https://github.com/billsioros/cookiecutter-pypackage">
    <img
      src="https://img.shields.io/badge/cookiecutter-template-D4AA00.svg?style=flat&logo=cookiecutter"
      alt="Cookiecutter Template">
  </a>
  <a href="https://app.renovatebot.com/dashboard#github/billsioros/cookiecutter-pypackage-instance">
    <img
      src="https://img.shields.io/badge/renovate-enabled-brightgreen.svg?style=flat&logo=renovatebot"
      alt="Renovate - Enabled">
  </a>
  <a href="https://www.buymeacoffee.com/billsioros">
    <img
      src="https://img.shields.io/badge/Buy%20me%20a-coffee-FFDD00.svg?style=flat&logo=buymeacoffee"
      alt="Buy me a coffee">
  </a>
</p>

## Example Usage

```python
>>> from cookiecutter_pypackage_instance import cookiecutter_pypackage_instance
```

## Features

- TODO

## Documentation

The project's documentation can be found [here](https://billsioros.github.io/cookiecutter-pypackage-instance/).

## Installation

```bash
pip install cookiecutter-pypackage-instance
```

## Supporting the project

Feel free to [**Buy me a coffee! ☕**](https://www.buymeacoffee.com/billsioros).

## Contributing

If you would like to contribute to the project, please go through the [Contributing Guidelines](https://billsioros.github.io/cookiecutter-pypackage-instance/latest/CONTRIBUTING/) first.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [billsioros/cookiecutter-pypackage](https://github.com/billsioros/cookiecutter-pypackage) cookiecutter template.
